@@ -906,7 +906,7 @@ class VExportTree:
         if bpy.context.preferences.addons['io_scene_gltf2'].preferences.KHR_materials_variants_ui is False:
             return
         objects = [self.nodes[o].blender_object for o in self.get_all_node_of_type(VExportNode.OBJECT) if self.nodes[o].blender_object.type == "MESH"
-                   and self.nodes[o].blender_object.data.get('gltf2_variant_default_materials') is not None]
+                   and self.nodes[o].blender_object.data.gltf2_variant_default_materials is not None]
         for obj in objects:
             # loop on material slots ( primitives )
             for mat_slot_idx, s in enumerate(obj.material_slots):
@@ -919,7 +919,7 @@ class VExportTree:
             # If not found, keep current material as default
 
     def break_bone_hierarchy(self):
-        # Can be usefull when matrix is not decomposable
+        # Can be useful when matrix is not decomposable
         for arma in self.get_all_node_of_type(VExportNode.ARMATURE):
             bones = self.get_all_bones(arma)
             for bone in bones:
@@ -931,7 +931,7 @@ class VExportTree:
                     self.nodes[bone].parent_bone_uuid = None
 
     def break_obj_hierarchy(self):
-        # Can be usefull when matrix is not decomposable
+        # Can be useful when matrix is not decomposable
         # TODO: if we get real collection one day, we probably need to adapt this code
         for obj in self.get_all_objects():
             if self.nodes[obj].armature is not None and self.nodes[obj].parent_uuid == self.nodes[obj].armature:
